A SnapBuf is like a Vec<u8> with cheap snapshotting using copy on write.
Internally, the data is broken up into segments that are organized in a tree structure. Only modified subtrees are cloned, so buffers with only little differences can share most of their memory. Moreover, subtrees which contain only zeros take up no memory.
Structs
- SnapBuf
- A copy on write buffer.
- Snap
BufCursor - A file-like abstraction around SnapBuf implementing std-io traits.