Struct SnapBuf

pub struct SnapBuf { /* private fields */ }

Implementations

Source

impl SnapBuf

pub fn new() -> Self

Creates an empty buffer.

pub fn resize(&mut self, new_len: usize, value: u8)

Resizes the buffer, to the given length.

If new_len is greater than len, the new space in the buffer is filled with copies of value. This is more efficient if value == 0.

pub fn truncate(&mut self, new_len: usize)

Shortens the buffer, keeping the first new_len bytes and discarding the rest.

If new_len is greater or equal to the buffer’s current length, this has no effect.

pub fn fill_range(&mut self, range: Range<usize>, value: u8)

Fill the given range with copies of value.

This is equivalent to calling write with a slice filled with value. Calling this with value = 0 is not guaranteed to free up the zeroed segments, use clear_range if that is required.

pub fn write(&mut self, offset: usize, data: &[u8])

Writes data at the specified offset.

If this extends past the current end of the buffer, the buffer is automatically resized. If offset is larger than the current buffer length, the space between the current buffer end and the written region is filled with zeros.

Zeroing parts of the buffer using this method is not guaranteed to free up the zeroed segments, use write_with_zeros if that is required.

pub fn write_with_zeros(&mut self, offset: usize, data: &[u8])

Like write, but detects and frees newly zeroed segments in the buffer.

pub fn is_empty(&self) -> bool

Returns true if the buffer length is zero.

pub fn len(&self) -> usize

Returns the length of the buffer, the number of bytes it contains.

The memory footprint of the buffer may be much smaller than this due to omission of zero segments and sharing with other buffers.

pub fn clear_range(&mut self, range: Range<usize>)

Fill a range with zeros, freeing memory if possible.

Panics

Panics if range end is range.end > self.len().

pub fn clear(&mut self)

Clears all data and sets length to 0.

pub fn chunks(&self) -> impl Iterator<Item = &[u8]>

Returns an iterator over the byte slices constituting the buffer.

The returned slices may overlap.

pub fn iter(&self) -> impl Iterator<Item = &u8>

Returns an iterator over the buffer.

pub fn extend_from_slice(&mut self, data: &[u8])